@@ -1,4 +1,4 @@
-from .aggregators import NewlineAggregator, SimpleAggregator, NetstringAggregator
+from .aggregators import NewlineAggregator, SimpleAggregator, NetstringAggregator, ListAggregator
 from .serializers import StringSerializer, JsonSerializer, MsgpackSerializer
 
 
@@ -18,5 +18,9 @@ class JsonLineProcessor(Processor, NewlineAggregator, JsonSerializer):
     pass
 
 
+class JsonListProcessor(Processor, ListAggregator, JsonSerializer):
+    pass
+
+
 class MsgpackProcessor(Processor, NetstringAggregator, MsgpackSerializer):
     pass
